from distutils.core import setup



setup(

            name = 'sunillist',

            version='1.1.0',

            py_modules = ['sunillist'],

            author = 'sunilshanbhogh',

            author_email = 'sunilshanbhogh@gmail.com',

            description = 'A simple printer of nested lists'

            )
            
            
